# JovialEngine
A Simple Pygame Engine

![test badge](https://github.com/JovialKnoll/jovialengine/actions/workflows/test.yml/badge.svg?branch=master)

If you're interested, please read the notes on [usage](https://raw.githubusercontent.com/JovialKnoll/jovialengine/master/usage.txt).
